==> gphys_0.3.4.orig.tar.gz: gphys-0.3.4.orig/doc/derivative/math-doc/document/images.pl <==
# LaTeX2HTML 2K.1beta (1.48)
# Associate images original text with physical files.


$key = q/displaystyle=(s^2+st^2)f'(x_i)+s^2O(t^3)+t^2O(s^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="314" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="$\displaystyle = (s^2 + st^2)f'(x_i) + s^2O(t^3) + t^2O(s^3)$">|; 

$key = q/f(x);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="41" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$ f(x)$">|; 

$key = q/displaystylef(x_{i+1}-x_{i});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="103" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$\displaystyle f(x_{i+1} - x_{i})$">|; 

$key = q/t^3;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="19" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="$ t^3$">|; 

$key = q/t;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$ t$">|; 

$key = q/displaystyle=O(t^2),;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="73" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="$\displaystyle = O(t^2),$">|; 

$key = q/displaystylef'(x_i);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="51" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="$\displaystyle f'(x_i)$">|; 

$key = q/t^2times;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="34" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="$ t^2\times$">|; 

$key = q/displaystyle=tf'(x_i)+frac{t^2}{2}(x_i)+O(t^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="216" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$\displaystyle = tf'(x_i) + \frac{t^2}{2}(x_i) + O(t^3)$">|; 

$key = q/displaystyleequivf(x_{i}-x_{i-1});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="123" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="$\displaystyle \equiv f(x_{i} - x_{i-1})$">|; 

$key = q/f'(x_i),F''(x_i);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="113" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="$ f'(x_i), F''(x_i)$">|; 

$key = q/x_i;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$ x_i$">|; 

$key = q/s^2times;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="36" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="$ s^2\times$">|; 

$key = q/displaystyles^2f_{i+1}+(t^2-s^2)f_i-t^2f_{i-1};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="229" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="$\displaystyle s^2f_{i+1} + (t^2 -s^2)f_i - t^2f_{i-1}$">|; 

$key = q/displaystyle=frac{s^2f_{i+1}+(t^2-s^2)f_i-t^2f_{i-1}}{st(s+t)};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="252" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="$\displaystyle = \frac{s^2f_{i+1} + (t^2 -s^2)f_i - t^2f_{i-1}}{st(s + t)}$">|; 

$key = q/displaystyle=-sf'(x_i)+frac{s^2}{2}(x_i)+O(s^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="237" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$\displaystyle = -sf'(x_i) + \frac{s^2}{2}(x_i) + O(s^3)$">|; 

$key = q/f;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$ f$">|; 

$key = q/displaystyle=f'(x_i)+frac{O(s^2t^3)+O(t^2s^3)}{st(s+t)};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="241" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="$\displaystyle = f'(x_i) + \frac{O(s^2t^3) + O(t^2s^3)}{st(s + t)}$">|; 

$key = q/displaystylet;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$\displaystyle t$">|; 

$key = q/s;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$ s$">|; 

$key = q/displaystylefrac{s^2f_{i+1}+(t^2-s^2)f_i-t^2f_{i-1}}{st(s+t)};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="335" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="$\displaystyle frac{s^2f_{i+1} + (t^2 -s^2)f_i - t^2f_{i-1}}{st(s + t)}$">|; 

$key = q/x;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="15" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$ x$">|; 

$key = q/x_n(x_0,x_1,...,x_{i},...,x_{n});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="184" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$ x_n (x_0, x_1, ..., x_{i}, ..., x_{n})$">|; 

$key = q/displaystylef_i;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$\displaystyle f_i$">|; 

$key = q/O(t^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="48" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="$ O(t^3)$">|; 

$key = q/displaystyleequivf(x_i);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="67" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$\displaystyle \equiv f(x_i)$">|; 

$key = q/displaystyleequivf(x_{i+1}-x_{i});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="123" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$\displaystyle \equiv f(x_{i+1} - x_{i})$">|; 

$key = q/f'';MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="$ f''$">|; 

$key = q/displaystyles;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$\displaystyle s$">|; 

$key = q/displaystylef(x_{i-1}-x_{i});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="103" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$\displaystyle f(x_{i-1} - x_{i})$">|; 

1;

==> gphys_1.5.4.orig.tar.gz: gphys-1.5.4/doc/derivative/math-doc/document/images.pl <==
# LaTeX2HTML 2K.1beta (1.48)
# Associate images original text with physical files.


$key = q/displaystyle=(s^2+st^2)f'(x_i)+s^2O(t^3)+t^2O(s^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="314" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="$\displaystyle = (s^2 + st^2)f'(x_i) + s^2O(t^3) + t^2O(s^3)$">|; 

$key = q/f(x);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="41" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$ f(x)$">|; 

$key = q/displaystyleequiv(x_{i}-x_{i-1});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="112" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="$\displaystyle \equiv (x_{i} - x_{i-1})$">|; 

$key = q/t^3;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="19" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="$ t^3$">|; 

$key = q/t;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$ t$">|; 

$key = q/displaystylef'(x_i);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="51" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="$\displaystyle f'(x_i)$">|; 

$key = q/t^2times;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="34" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="$ t^2\times$">|; 

$key = q/displaystyle=tf'(x_i)+frac{t^2}{2}f''(x_i)+O(t^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="235" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$\displaystyle = tf'(x_i) + \frac{t^2}{2}f''(x_i) + O(t^3)$">|; 

$key = q/x_i;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$ x_i$">|; 

$key = q/f'(x_i),f''(x_i);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="109" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="$ f'(x_i), f''(x_i)$">|; 

$key = q/s^2times;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="36" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="$ s^2\times$">|; 

$key = q/displaystyles^2f_{i+1}+(t^2-s^2)f_i-t^2f_{i-1};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="229" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="$\displaystyle s^2f_{i+1} + (t^2 -s^2)f_i - t^2f_{i-1}$">|; 

$key = q/displaystyle=frac{s^2f_{i+1}+(t^2-s^2)f_i-t^2f_{i-1}}{st(s+t)};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="252" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="$\displaystyle = \frac{s^2f_{i+1} + (t^2 -s^2)f_i - t^2f_{i-1}}{st(s + t)}$">|; 

$key = q/f;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$ f$">|; 

$key = q/displaystyle=f'(x_i)+frac{O(s^2t^3)+O(t^2s^3)}{st(s+t)};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="241" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="$\displaystyle = f'(x_i) + \frac{O(s^2t^3) + O(t^2s^3)}{st(s + t)}$">|; 

$key = q/displaystyle=O(t^2).;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="73" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="$\displaystyle = O(t^2).$">|; 

$key = q/displaystylet;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$\displaystyle t$">|; 

$key = q/displaystyle=-sf'(x_i)+frac{s^2}{2}f''(x_i)+O(s^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="256" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$\displaystyle = -sf'(x_i) + \frac{s^2}{2}f''(x_i) + O(s^3)$">|; 

$key = q/s;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$ s$">|; 

$key = q/displaystylefrac{s^2f_{i+1}+(t^2-s^2)f_i-t^2f_{i-1}}{st(s+t)};MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="233" HEIGHT="64" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="$\displaystyle \frac{s^2f_{i+1} + (t^2 -s^2)f_i - t^2f_{i-1}}{st(s + t)}$">|; 

$key = q/displaystyleequiv(x_{i+1}-x_{i});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="112" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$\displaystyle \equiv (x_{i+1} - x_{i})$">|; 

$key = q/displaystylef(x_{i-1})-f(x_{i});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="129" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$\displaystyle f(x_{i-1}) - f(x_{i})$">|; 

$key = q/displaystylef(x_{i+1})-f(x_{i});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="129" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$\displaystyle f(x_{i+1}) - f(x_{i})$">|; 

$key = q/x_n(x_0,x_1,...,x_{i},...,x_{n});MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="184" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$ x_n (x_0, x_1, ..., x_{i}, ..., x_{n})$">|; 

$key = q/x;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="15" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$ x$">|; 

$key = q/displaystylef_i;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$\displaystyle f_i$">|; 

$key = q/O(t^3);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="48" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="$ O(t^3)$">|; 

$key = q/displaystyleequivf(x_i);MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="67" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$\displaystyle \equiv f(x_i)$">|; 

$key = q/f'';MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="$ f''$">|; 

$key = q/displaystyles;MSF=1.6;LFS=12;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$\displaystyle s$">|; 

1;
